*====================================================================================================*
*                                  preparation.do                                                    *
*====================================================================================================*

*----------------------------------------------------------------------------------------------------*
*  Lechner & Leopold 2014, replication files                                                         *
*  last update: 21-10-14                                                                             *
*  data: soeplong 1984-2012, version 29, release 2013                                                *
*----------------------------------------------------------------------------------------------------*

/*
We select two analytical samples: 
Sample 1 includes individuals who are observed across the transition to their first parent's death.
Sample 2 includes individuals who are observed across the transition to their second parent's death.

This dofile generates the file "data", on which all analyses are based;
"data" is a long-format dataset. Every row represents a person-year.
*/




*----------------------------------------------------------------------------------------------------*
* 1. Select variables                                                                                *
*----------------------------------------------------------------------------------------------------*

* Load pl (main person file; long format)

use "${data}/pl.dta", clear


* Set label language to English

label language EN


* Sort and keep only relevant variables

sort pid (syear)
keep 	pid syear 		///
		plh0182   		/// Outcome variable: Life satisfaction
		pld0160 pld0163	/// Death years of parents (from panel)
		pcd0020 pcd0022	/// Death years of parents (from retrospective questionnaires)
		plb0021 ple0008	//  Unemployment and self-rated health

		
* Merge

merge 1:1 pid syear using "$dataDir\pgen.dta", ///
 	  keepusing (pgfamstd pgemplst) 		   /// Marital status, employment status
	  keep (1 3) nogen
merge m:1 pid using "$dataDir\ppfad.dta", 	   ///
	  keepusing (sex gebjahr) 				   /// Gender, year of birth				
	  keep (1 3) nogen
merge 1:1 pid syear using "$dataDir\bio.dta",  	      ///
      keepusing (l0080 l0081 l0082 l0083 l0373 l0375) /// Parents' years of birth and death
	  keep (1 3) nogen


*----------------------------------------------------------------------------------------------------*
* 2. Define parents' years of death                                                                  *
*----------------------------------------------------------------------------------------------------*

/*
There are three variables for the father's year of death and three for the mother's year of death.
This information is available in the panel questionnaire (pld0160, pld0163) 
and in retrospective questionnaires (l0080 l0081 l0373 l0375 pcd0020 pcd0022).
We combine this information (starting with the panel measures) into common indicators.
*/

* Decode missings

mvdecode pld0160 pld0163 pcd0020 pcd0022 l0080 l0081 l0373 l0375, ///
		 mv(-8, -3, -2, -1, 0)

		 
* Correct measures from biographical questionnaires

replace l0080 = l0080 + 1900 if l0080 < 100				
// some values in this variable have only two digits for years after 1900
replace l0081 = l0081 + 1900 if l0081 < 100				
// some values in this variable have only two digits for years after 1900
replace pcd0020 = pcd0020 + 1000 if pcd0020 < 1000		
// some values in this variable have only three digits for years after 1000
replace pcd0022 = pcd0022 + 1000 if pcd0022 < 1000		
// some values in this variable have only three digits for years after 1000


* Define death years from panel measures

bysort pid (syear): gen nr = _n 						
// nr counts number of panel observations for each respondent

** Father
gen aux = nr if pld0160 == 1							
// aux indicates the number of the panel observation in which the father died						
bysort pid (syear): egen aux1 = min(aux) 				
// aux1 writes the number of the panel observation in which the father died in every row			
gen fdead = 0
replace fdead = 1 if aux == aux1 & aux!=. 
// fdead is 1 in the survey year in which the father died (i.e., aux is non-missing and equal to aux1)
drop aux aux1

** Mother
gen aux = nr if pld0163 == 1							
// aux indicates the number of the panel observation in which the mother died				
bysort pid (syear): egen aux1 = min(aux) 				
// aux1 writes the number of the panel observation in which the mother died in every row	
gen mdead = 0
replace mdead = 1 if aux == aux1 & aux!=. 				
// mdead is 1 in the survey year in which the mother died (i.e., aux is non-missing and equal to aux1)
drop aux aux1


* Define common measures

** Father
gen f_y = .
replace f_y = syear if fdead == 1			
// start with death year from panel observations
replace f_y = l0080 if f_y == . & l0080 != .	
// add information from biographical questionnaire
replace f_y = l0373 if f_y == . & l0373 != .	
// add further information from biographical questionnaire
replace f_y = pcd0020 if f_y == . & pcd0020 != .	
// add information family history questionnaire
bysort pid (syear): egen f_year = max(f_y)		
// integrate all information into a variable for father's year of death

** Mother
gen m_y = .
replace m_y = syear if mdead == 1									
// start with death year from panel observations
replace m_y = l0081 if m_y == . & l0081 != .						
// add information from biographical questionnaire
replace m_y = l0375 if m_y == . & l0375 != .						
// add further information from biographical questionnaire
replace m_y = pcd0022 if m_y == . & pcd0022 != .					
// add information family history questionnaire
bysort pid (syear): egen m_year = max(m_y)							
// integrate all information into a variable for mother's year of death

** First parent and second parent
egen fp_year = rowmin(f_year m_year)								
// first parent's year of death is the minimum of both variables
egen sp_year = rowmax(f_year m_year) if f_year != . & m_year != .	
// second parent's year of death is the maximum of both variables (if both are non-missing)


* Clean up: Drop variables that are no longer necessary

drop pld0160 pld0163 l0080 l0081 l0373 l0375 pcd0020 pcd0022 nr f_y m_y


*----------------------------------------------------------------------------------------------------*
* 3. Select samples                                                                                  *
*----------------------------------------------------------------------------------------------------*

/* 
Sample 1: Death of the first parent
Criteria for inclusion
	1. Both parents alive at first observation
	2. At least one parent died across the observation window
	3. At least one observation per respondent before and after the transition

Sample 2: Death of the second parent
Criteria for inclusion
	1. At least one parent alive at first observation
	2. Second parent died across the observation window
	3. At least one observation per respondent before and after the transition
*/

* Generate indicators for years of first and last observation in the data

bysort pid (syear): gen nr = _n							
// Generate enumerator for panel observations of each individual
gen aux = syear if nr == 1								
// aux indicates the survey year of first observation
bysort pid (syear): egen first_obs = max(aux)			
// write aux (year of first observation) into every observation of an individual
bysort pid (syear): egen aux1 = max(nr)					
gen aux2 = syear if nr == aux1							
// aux2 indicates the survey year of last observation
bysort pid (syear): egen last_obs = max(aux2)			
// write aux2 (year of last observation) into every observation of an individual
drop aux aux1 aux2 nr


* Generate variable to select Sample 1 (death of the first parent)

gen fp_sample = 			///
	fp_year != . 			/// first parent has died
	& (first_obs < fp_year) /// death year is after first observation
	& (last_obs > fp_year)	//  death year is before last observation
// Set to zero if both parents died in the same year
gen same_year = f_year == m_year
replace fp_sample = 0 if fp_sample == 1 & same_year == 1


* Generate variable to select Sample 2 (death of the second parent)

gen sp_sample = 			/// 
	sp_year != . 			/// second parent has died
	& (first_obs < sp_year) /// death year is after first observation
	& (last_obs > sp_year)	//  death year is before last observation
// Set to zero if both parents died in the same year
replace sp_sample = 0 if sp_sample == 1 & same_year == 1


* Drop if not included in either sample

drop if !fp_sample & !sp_sample


* Drop observations in old age (see Clark et al., 2008)

gen age = syear - gebj
drop if age > 70


*----------------------------------------------------------------------------------------------------*
* 4. Generate analytical variables                                                                   *
*----------------------------------------------------------------------------------------------------*

* Outcome: Life satisfaction / subjective well-being (11-point scale, measured annually since 1984)

replace plh0182 = . if plh0182 < 0 
// Decode missings
clonevar swb = plh0182


* Indicator variables for the death of the first and second parent

gen fp_dead  = syear == fp_year							
// Time-changing variable: 1 in the year of the first parent's death
gen f_first  = fp_year != . & (fp_year == f_year)		
// Time constant variable: 1 if father died first
gen m_first  = fp_year != . & (fp_year == m_year)		
// Time constant variable: 1 if mother died first
gen sp_dead  = syear == sp_year							
// Time-changing variable: 1 in the year of the second parent's death
gen f_second = sp_year != . & (sp_year == f_year)		
// Time constant variable: 1 if father died second
gen m_second = sp_year != . & (sp_year == m_year)		
// Time constant variable: 1 if mother died second


* Index variables for years before and after each events 
// We consider a maximum of 5 years before and after each event

** First parent
bysort pid (syear): gen aux = syear if fp_dead == 1 & fp_sample == 1			
// aux is the year in which the first parent died ( if included in sample 1)
bysort pid (syear): egen aux1 = max(aux)
bysort pid (syear): gen aux2 = syear - aux1										
// aux2 counts years before and after the first parent's death (0 in year of death)
gen fp_index = .
replace fp_index = aux2 if inrange(aux2, -5, 5)									
// fp_index includes all values of aux2 included in the range -5 to 5 (else missing)
recode  fp_index 	           ///
		(-5/-2 = 1 "-5 to -2") ///
		(-1    = 2 "-1")       ///
		(0     = 3 "0")        ///
		(1     = 4 "1")        ///
		(2/3   = 5 "2 to 3")   ///
		(4/5   = 6 "4 to 5")   ///
	, gen(fp_time)		
// fp_time is a positive numeric recode of fp_index
drop aux aux1 aux2

/// Second parent
bysort pid (syear): gen aux = syear if sp_dead == 1 & sp_sample == 1			
// aux is the year in which the second parent died ( if included in sample 2)
bysort pid (syear): egen aux1 = max(aux)
bysort pid (syear): gen aux2 = syear - aux1										
// aux2 counts years before and after the second parent's death (0 in year of death)
gen sp_index = .
replace sp_index = aux2 if inrange(aux2, -5, 5)									
// sp_index includes all values of aux2 included in the range -5 to 5 (else missing)
recode  sp_index 	           ///
		(-5/-2 = 1 "-5 to -2") ///
		(-1    = 2 "-1")       ///
		(0     = 3 "0")        ///
		(1     = 4 "1")        ///
		(2/3   = 5 "2 to 3")   ///
		(4/5   = 6 "4 to 5")   ///
	, gen(sp_time)	
	// sp_time is a positive numeric recode of sp_index (requirement for factor variables)
drop aux aux1 aux2


* Gender

replace sex = 0 if sex == 2							


* Child's age at parents' death

gen aux = age if fp_dead == 1
bysort pid (syear): egen fp_age_at = max(aux)		
// child's age at first parent's death
sum aux,d											
gen aux1 = aux - r(p50)								
bysort pid (syear): egen fp_age_at_c = max(aux1)	
// child's age at first parent's death - median-centered
drop aux aux1
gen aux = age if sp_dead == 1
bysort pid (syear): egen sp_age_at = max(aux)		
// child's age at second parent's death
sum aux,d											
gen aux1 = aux - r(p50)
bysort pid (syear): egen sp_age_at_c = max(aux1) 	
// child's age at second parent's death - median-centered
drop aux aux1


* Controls

** Age (categorical to reduce collinearity with the time variable)
recode 	 age 	 	///
		(0/30 = 1)  ///
		(31/35 = 2) ///
		(36/40 = 3) ///
		(41/45 = 4) ///
		(46/50 = 5) /// 
		(51/55 = 6) ///
		(56/60 = 7) ///
		(61/65 = 8) ///
		(66/70 = 9) ///
	, gen(age_cat)

** Period (categorical to reduce collinearity with the time and age variables)
recode   syear 					  ///
		(1984/1988 = 1 "1984-88") ///
		(1989/1993 = 2 "1989-93") ///
		(1994/1998 = 3 "1994-98") ///
		(1999/2003 = 4 "1999-03") ///
		(2004/2008 = 5 "2004-08") ///
		(2009/2012 = 6 "2009-12") ///
	, gen (period)  


** Marital status
mvdecode pgfamstd, mv(-2 -1)						
recode   pgfamstd   ///
		(3     = 1 "Single")   ///
		(1 2 6 = 2 "Married")  ///
		(4     = 3 "Divorced") ///
		(5     = 4 "Widowed")  ///
	, gen(mar)


** Employment
mvdecode pgemplst, mv(-2 -1 6)
gen emp_full  = pgemplst  == 1 & plb0021 != 1						
// full-time employed (and not concurrently unemployed; this applies to some cases)
gen emp_part  = (pgemplst == 2 | pgemplst == 4) & plb0021 != 1		
// part-time employed (and not concurrently unemployed; this applies to some cases)
gen emp_educ  = pgemplst  == 3 & plb0021 != 1						
// in education (and not concurrently unemployed; this applies to some cases)
gen emp_not   = pgemplst  == 5 & plb0021 != 1						
// not employed (and not concurrently unemployed; this applies to some cases)
gen emp_unemp = plb0021   == 1										
// unemployed (set to 1 if unemployed even if concurrently reported any other status)
gen emp = .															
replace emp = 1 if emp_full
replace emp = 2 if emp_part
replace emp = 3 if emp_educ
replace emp = 4 if emp_not
replace emp = 5 if emp_unemp	
label define e 1 "Full time" 2 "Part time" 3 "In education" 4 "Not employed" 5 "Unemployed"
label values emp e

** Self-rated health (5-point scale, measured since 1992 and annually since 1994)
replace ple0008 = . if ple0008 < 0 
clonevar srh = ple0008		
replace srh = 0 if srh == .							
// 0 is translated into a flag variable for missing values

** Controls for first and second parent's death
// Note: We net out each event's effects from the temporal profiles of the other
** First parent
gen fp_control = 0
forvalues i = 1/6 {
	replace fp_control = `i' if fp_time == `i'
	}
** Second parent
gen sp_control = 0
forvalues i = 1/6 {
	replace sp_control = `i' if sp_time == `i'
	}
*


* Variables used for sample description

** Parent's age at death
replace l0082 = . if l0082 <= 1850 					
// set implausible values to missing
replace l0083 = . if l0083 < 0 	  					
// decode missings
replace l0082 = l0082 + 1000 if l0082 < 1000		
// standardize measurement to calendar years
replace l0083 = l0083 + 1000 if l0083 < 1000		
// standardize measurement to calendar years
gen aux = f_year - l0082
bysort pid (syear): egen f_page_at = max(aux)		
// father's age at death
gen aux1 = m_year - l0083
bysort pid (syear): egen m_page_at = max(aux1)		
// mother's age at death
drop aux aux1
gen fp_page_at = .									
// first parent's age at death
replace fp_page_at = f_page_at if f_first == 1
replace fp_page_at = m_page_at if m_first == 1
gen sp_page_at = .									
// second parent's age at death
replace sp_page_at = f_page_at if f_second == 1
replace sp_page_at = m_page_at if m_second == 1
// -- Clean data --
drop if fp_page_at == 22  // drop one implausible case

** Parent's year of birth
gen aux = .
replace aux = l0082 if f_first == 1					
// insert father's year of birth if father died first
replace aux = l0083 if m_first == 1					
// insert mother's year of birth if mother died first
bysort pid (syear): egen fp_byear = max(aux)		
// insert value in every row of a respondent
gen aux1 = .
replace aux1 = l0082 if f_second == 1				
// insert father's year of birth if father died second
replace aux1 = l0083 if m_second == 1				
// insert mother's year of birth if mother died second
bysort pid (syear): egen sp_byear = max(aux1)		
// insert value in every row of a respondent
drop aux aux1


*----------------------------------------------------------------------------------------------------*
* 5. Order, label, and clean variables                                                               *
*----------------------------------------------------------------------------------------------------*

drop first_obs last_obs fdead mdead plb0021 ple0008 plh0182 pgfamstd pgemplst l0082 l0083

label variable swb				"Life satisfaction (0-10 scale)"
label variable sex				"Sex: Male"
label variable srh				"Self-rated health"
label variable gebjahr			"Birth year of respondent"
label variable fp_sample 		"Select sample 1 (first parent's death)"
label variable sp_sample 		"Select sample 1 (second parent's death)"
label variable f_year 			"Father's calendar year of death"
label variable m_year 			"Mother's calendar year of death"
label variable fp_year 			"First parent's calendar year of death"
label variable sp_year 			"Second parent's calendar year of death"
label variable f_first 			"Father died first"
label variable m_first 			"Mother died first"
label variable f_second 		"Father died second"
label variable m_second 		"Mother died second"
label variable fp_index 		"Years before/after first parent's death"
label variable sp_index 		"Years before/after second parent's death"
label variable fp_dead 			"First parent's year of death (binary indicator)"
label variable sp_dead 			"Second parent's year of death (binary indicator)"
label variable fp_time 			"Years before/after death of first parent"
label variable sp_time 			"Years before/after death of second parent"
label variable same_year		"Both parents died in the same year"
label variable mar				"Marital status"
label variable emp				"Employment status"
label variable age 				"Age"
label variable age_cat			"Age (categorical)"
label variable period 			"Period"	
label variable fp_age_at 		"Respondent's age at first parent's death"
label variable fp_age_at_c 		"Respondent's age at first parent's death (median-centered)"
label variable sp_age_at 		"Respondent's age at second parent's death"
label variable sp_age_at_c 		"Respondent's age at second parent's death (median-centered)"
label variable f_page_at 		"Father's age at death"	
label variable m_page_at 		"Mother's age at death"
label variable fp_page_at 		"First parent's age at death"	
label variable sp_page_at 		"Second parent's age at death"
label variable fp_byear 		"Birth year of parent who died first"
label variable sp_byear 		"Birth year of parent who died second"	
label variable fp_control		"Controls for death of first parent"
label variable sp_control		"Controls for death of second parent"

order 	pid syear sex gebjahr age fp_sample sp_sample swb ///
		fp_time sp_time age_cat period mar emp srh fp_control sp_control
order   pid-fp_dead sp_dead


*----------------------------------------------------------------------------------------------------*
*----------------------------------------------------------------------------------------------------*
		
* Save to folder 03/posted

save "${workingDir}/03_posted/data", replace

*----------------------------------------------------------------------------------------------------*
*----------------------------------------------------------------------------------------------------*
