*====================================================================================================*
*                                  analysis.do                                                       *
*====================================================================================================*

*----------------------------------------------------------------------------------------------------*
*  Lechner & Leopold 2014, replication files                                                         *
*  last update: 25-08-14                                                                             *
*  data: soeplong 1984-2012, version 29, release 2013                                                *
*----------------------------------------------------------------------------------------------------*


* Load prepared data
use "$posted/data", clear


*----------------------------------------------------------------------------------------------------*
* Table 1 & Table 2                                                                                  *
*----------------------------------------------------------------------------------------------------*

* Prepare variables for description

** Marital status: Generate dummy variables from categorical variable
tab mar, gen(mar)
	rename mar1 single
	rename mar2 married
	rename mar3 divorced
	rename mar4 widowed

** Consider missing values in self-rated health
gen srh1 = srh
replace srh1 = . if srh1 ==0 

** Generate indicator variables to restrict the description to observations that enter the analysis
gen fp_in = .
replace fp_in = 1 if fp_time != .		
// fp_in equals 1 in observation that enter the analysis of first parent's death
gen sp_in = .
replace sp_in = 1 if sp_time != .		
// sp_in equals 1 in observation that enter the analysis of second parent's death


* Table 1

eststo tc_fp:  estpost sum f_first fp_byear fp_year fp_page sex gebj fp_age_at  if fp_time == 3	   
// sp_time == 3 --> year of first parent's death
eststo tc_sp:  estpost sum f_second sp_byear sp_year sp_page sex gebj sp_age_at if sp_time == 3    
// sp_time == 3 --> year of first parent's death

esttab tc_fp using "$tables/table1.rtf", replace label ///
	cells("mean(fmt(a2)) sd(fmt(a2)) min(fmt(a2)) max(fmt(a2)) count(fmt(a2))")
esttab tc_sp using "$tables/table1.rtf", append label  ///
	cells("mean(fmt(a2)) sd(fmt(a2)) min(fmt(a2)) max(fmt(a2)) count(fmt(a2))")


* Table 2

eststo tv_fp: estpost tabstat swb age single married divorced widowed emp_* srh1 if fp_in == 1, ///
	stat(mean) by(fp_time)
eststo tv_sp: estpost tabstat swb age single married divorced widowed emp_* srh1 if sp_in == 1, ///
	stat(mean) by(sp_time)
esttab tv_fp using "$tables/table2.rtf", replace label ///
	cells("mean(fmt(a2)) swb age single married divorced widowed emp_full emp_part emp_educ emp_not emp_unemp srh1")
esttab tv_sp using "$tables/table2.rtf", append label  ///
	cells("mean(fmt(a2)) swb age single married divorced widowed emp_full emp_part emp_educ emp_not emp_unemp srh1")


* Additional descriptives: Parent's age at death and child's age at parent's death

bysort pid (syear): gen n =_n
// Correlation
cor fp_age_at fp_page_at if n == 1 & fp_sample == 1 
// Child <= 30
tab fp_page_at if fp_sample == 1 & n == 1 & fp_age_at <= 30
// Child > 50
tab fp_page_at if fp_sample == 1 & n == 1 & fp_age_at > 50


*----------------------------------------------------------------------------------------------------*
* 2. Table 3 & Figure 1                                                                              *
*----------------------------------------------------------------------------------------------------*

* Table 3

/*
Model 1: Death of the first parent
Model 2: Death of the second parent.

The models estimate linear change in life satisfaction (11-point scale), with person-level 
fixed-effects (i.e., respondents serve as their own controls). The constant 
is defined for the following constellation of reference categories:
	- "2-5 years before death of first parent" 									(ib1.fp_time)
	- "aged 46 to 50" 															(ib5.age_cat)
	- "period 1999 to 2003" 													(ib4.period)
 	- "single" 																	(ib1.mar)
 	- "working fulltime" 														(ib1.emp)
	- "acceptable health" 														(ib3.srh)
	- "not within 11-years interval surrounding death of first/second parent"  	(ib0.fp/sp_control)
*/

** Load prepared data and set to panel data
use "$posted/data", clear
xtset pid syear

** Model 1: First parent
eststo: xtreg 	swb 			///
				ib1.fp_time 	///
				ib5.age_cat 	///	
				ib4.period 		///
				ib1.mar 		///
				ib1.emp 		///
				ib3.srh 		///
				ib0.sp_control	///
		, fe

** Rename sp_time to estimate the identically named measure		
drop fp_time
rename sp_time fp_time	

** Model 2: Second parent
eststo: xtreg 	swb 			///
				ib1.fp_time 	///
				ib5.age_cat 	///	
				ib4.period 		///
				ib1.mar 		///
				ib1.emp 		///
				ib3.srh 		///
				ib0.fp_control	///
		, fe

** Export Table 3 to Word
esttab using "$tables/table3.rtf", replace label wide ///
	se starlevels(+ 0.10 * 0.05 ** 0.01)              ///
	mtitles("Model 1: First parent" "Model 2: Second parent")	


* Figure 1

/*
Figure 1 provides a graphical illustration of the results from Model 1 and Model 2.
*/

** Load prepared data and set to panel data
use "$posted/data", clear
xtset pid syear

** Model 1: First parent
xtreg 	swb 			///
		ib1.fp_time		///	 
		ib5.age_cat 	///
		ib4.period 		///
		ib1.mar 		///
		ib1.emp 		///
		ib3.srh 		///
		ib0.sp_control	///
	, fe	
margins fp_time, vsquish post
est store A

** Rename sp_time to estimate the identically named measure
drop fp_time
rename sp_time fp_time 

** Model 2: Second parent
xtreg 	swb 			///
		ib1.fp_time		///	 
		ib5.age_cat 	///
		ib4.period 		///
		ib1.mar 		///
		ib1.emp 		///
		ib3.srh 		///
		ib0.fp_control	///
	, fe
margins fp_time, vsquish post
est store B

coefplot ///
	(A, label(First parent)  offset(0)	msymbol(O) mcolor(black) msize(medlarge) lcolor(black)  ///
		lwidth(medthick) lcolor(black)  ciopts(recast(rcap) lcolor(black))) 					///
	(B, label(Second parent) offset(0)	msymbol(S) mcolor(gs9)   		         lcolor(gs9)    ///
		lwidth(medthick) lcolor(gs9)    ciopts(recast(rcap) lcolor(gs9)))   					///
	, 	title 	("") 																			///	
				vertical recast(connected) ytitle("") ylab (7.1 (0.1) 6.6, 						///
				labsize(small) angle(0)) xtitle("") xlab (, labsize(small)) legend(size(small)) ///
				xtitle("Years before/after death of the parent", size(small)) 					///
				xscale(titlegap(2))									   							///
				graphregion(color(white) fcolor(white) icolor(white)) 							///
	saving("$graphs/figure_1.gph", replace)
	


*----------------------------------------------------------------------------------------------------*
* 3. Table 4 & Figure 2                                                                              *
*----------------------------------------------------------------------------------------------------*

* Table 4

/*
Models 3, 4 and 5 focus only in the death of the first parent.
In addition to the previous specification (Model 1), these models include interactions
between the time variable (fp_time) and 
	(1) respondents' age at first parent's death 			(fp_time##fp_age_at_c)
	(2) respondents' gender	(1 = male)						(fp_time##sex)
	(3) respondents' age at first parent's death and gender	(fp_time##fp_age_at_c##sex)

We estimate the following three models:
	Model 3: First parent: All
	Model 4: First parent: Mother
	Model 5: First parent: Father

All models estimate linear change in life satisfaction (11-point scale), 
with person-level fixed-effects (i.e., respondents serve as their own controls). The constant 
is defined for the following constellation of reference categories:
	- "2-5 years before death of first parent" 									(ib1.fp_time)
	- "aged 46 to 50" 															(ib5.age_cat)
	- "period 1999 to 2003" 													(ib4.period)
 	- "single" 																	(ib1.mar)
 	- "working fulltime" 														(ib1.emp)
	- "acceptable health" 														(ib3.srh)
	- "not within 11-years interval surrounding death of first/second parent"  	(ib0.sp_control)
*/

** Load prepared data and set to panel data
use "$posted/data", clear
xtset pid syear
	
** Estimate Models 3, 4, and 5
foreach var of varlist m_first f_first {
	eststo: xtreg 	swb 						///
					ib1.fp_time##c.fp_age_at_c 	///
					ib1.fp_time##ib0.sex 		///
					ib5.age_cat 				///
					ib4.period 					///
					ib1.mar 					///
					ib1.emp 					///
					ib3.srh 					///
					ib0.sp_control 				///
				if `var' == 1, fe
}

** Export Table 4 to Word
esttab using "$tables/table4.rtf", replace label se 	///
	wide starlevels(+ 0.10 * 0.05 ** 0.01) mtitles 		///
	("Model 3 Mothers" "Model 4 Fathers")
	
est clear


* Figure 2

/*	
Figure 2 plots the results from Model 3. Figure 3 plots the results from Model 4 and Model 5. 
In each graph, respondent's age at parent's death is fixed at three values, 30, 40, and 50. 
Because the median age at first parent's death is 46, the corresponding values are -16, -6, and 4.
All control variables are fixed at the values of their reference categories. 
See above for details on the estimation.
*/

foreach var of varlist m_first f_first {
		
		xtreg 	swb 								///
				ib1.fp_time##c.fp_age_at_c 			///
				ib1.fp_time##ib0.sex 				///
				ib5.age_cat 						///
				ib4.period 							///
				ib1.mar 							///
				ib1.emp 							///
				ib3.srh 							///
				ib0.sp_control 						///
			if `var' == 1, fe
		
		margins fp_time, at 						///
			   (fp_time=(1) 						///
				sex=(0) 							/// Daughter (0)
				fp_age_at_c=(-16) 					/// Aged 30 (46 - 16)
				age_cat=(5) 						///
				period=(4) 							///
				mar=(1) 							///
				emp=(1) 							///
				srh=(3) 							///
				sp_control=(0)) 					///
			vsquish noestimcheck post
	
		est store D30_`var'
	
	
		xtreg 	swb 								///
				ib1.fp_time##c.fp_age_at_c 			///
				ib1.fp_time##ib0.sex 				///
				ib5.age_cat 						///
				ib4.period 							///
				ib1.mar 							///
				ib1.emp 							///
				ib3.srh 							///
				ib0.sp_control 						///
			if `var' == 1, fe
		
		margins fp_time, at 						///
			   (fp_time=(1) 						///
				sex=(1) 							/// Son (1)
				fp_age_at_c=(-16) 					/// Aged 30 (46 - 16)
				age_cat=(5) 						///
				period=(4) 							///
				mar=(1) 							///
				emp=(1) 							///
				srh=(3) 							///
				sp_control=(0)) 					///
			vsquish noestimcheck post
	
		est store S30_`var'
	
	
		xtreg 	swb 								///
				ib1.fp_time##c.fp_age_at_c			/// 
				ib1.fp_time##ib0.sex 				///
				ib5.age_cat 						///
				ib4.period 							///
				ib1.mar 							///
				ib1.emp 							///
				ib3.srh 							///
				ib0.sp_control 						///
			if `var' == 1, fe
		
		margins fp_time, at 						///
			   (fp_time=(1) 						///
				sex=(0) 							/// Daughter (0)
				fp_age_at_c=(-6) 					/// Aged 40 (46 - 6)
				age_cat=(5) 						///
				period=(4) 							///
				mar=(1) 							///
				emp=(1) 							///
				srh=(3) 							///
				sp_control=(0)) 					///
			vsquish noestimcheck post
	
		est store D40_`var'	
	
	
		xtreg 	swb 								///
				ib1.fp_time##c.fp_age_at_c 			///
				ib1.fp_time##ib0.sex 				///
				ib5.age_cat 						///
				ib4.period 							///
				ib1.mar 							///
				ib1.emp 							///
				ib3.srh 							///
				ib0.sp_control 						///
			if `var' == 1, fe
		
		margins fp_time, at 						///
			   (fp_time=(1) 						///
				sex=(1) 							/// Son (1)
				fp_age_at_c=(-6) 					/// Aged 40 (46 - 6)
				age_cat=(5) 						///
				period=(4) 							///
				mar=(1) 							///
				emp=(1) 							///
				srh=(3) 							///
				sp_control=(0)) 					///
			vsquish noestimcheck post
	
		est store S40_`var'			
	
	
		xtreg 	swb 								///
				ib1.fp_time##c.fp_age_at_c 			///
				ib1.fp_time##ib0.sex 				///
				ib5.age_cat 						///
				ib4.period 							///
				ib1.mar 							///
				ib1.emp 							///
				ib3.srh 							///
				ib0.sp_control 						///
			if `var' == 1, fe
		
		margins fp_time, at 						///
			   (fp_time=(1) 						///
				sex=(0) 							/// Daughter (0)
				fp_age_at_c=(4) 					/// Aged 50 (46 + 4)
				age_cat=(5) 						///
				period=(4) 							///
				mar=(1) 							///
				emp=(1) 							///
				srh=(3) 							///
				sp_control=(0)) 					///
			vsquish noestimcheck post
	
		est store D50_`var'	

		
		xtreg 	swb 								///
				ib1.fp_time##c.fp_age_at_c 			///
				ib1.fp_time##ib0.sex 				///
				ib5.age_cat 						///
				ib4.period 							///
				ib1.mar 							///
				ib1.emp 							///
				ib3.srh 							///
				ib0.sp_control 						///
			if `var' == 1, fe
		
		margins fp_time, at 						///
			   (fp_time=(1) 						///
				sex=(1) 							/// Son (1)
				fp_age_at_c=(4) 					/// Aged 50 (46 + 4)
				age_cat=(5) 						///
				period=(4) 							///
				mar=(1) 							///
				emp=(1) 							///
				srh=(3) 							///
				sp_control=(0)) 					///
			vsquish noestimcheck post
	
		est store S50_`var'	

}	
*

** Mother's death
	coefplot ///
		(D50_m_first, label(Daughter  Age 50) offset(0) msymbol(T) mcolor(gs12)  lcolor(gs12)  lwidth(medthick) lcolor(gs12)  noci) ///		
		(S50_m_first, label(Son  Age 50)      offset(0) msymbol(T) mcolor(black) lcolor(black) lwidth(medthick) lcolor(black) noci) ///		
		(D40_m_first, label(Daughter  Age 40) offset(0) msymbol(D) mcolor(gs12)  lcolor(gs12)  lwidth(medthick) lcolor(gs12)  noci) ///		
		(S40_m_first, label(Son  Age 40)      offset(0) msymbol(D) mcolor(black) lcolor(black) lwidth(medthick) lcolor(black) noci) ///
		(D30_m_first, label(Daughter  Age 30) offset(0) msymbol(S) mcolor(gs12)  lcolor(gs12)  lwidth(medthick) lcolor(gs12)  noci) ///
		(S30_m_first, label(Son  Age 30)      offset(0) msymbol(S) mcolor(black) lcolor(black) lwidth(medthick) lcolor(black) noci) ///
	, title 	("Mother's death", size(small)) 												///
				vertical recast(connected)  													///
				ytitle("") ylab (6.8 (0.1) 6.0, labsize(small) angle(0)) 						///
				xtitle("Years before/after death of the first parent", size(small)) 			///
				xlab (, labsize(small)) xscale(titlegap(2))									    ///
				legend(size(small) rows(3)) 													///
				graphregion(color(white) fcolor(white) icolor(white)) 							///
	name (fig_m, replace)	

** Father's death
	coefplot ///
		(D50_f_first, label(Daughter  Age 50) offset(0) msymbol(T) mcolor(gs12)  lcolor(gs12)  lwidth(medthick) lcolor(gs12)  noci) ///		
		(S50_f_first, label(Son  Age 50)      offset(0) msymbol(T) mcolor(black) lcolor(black) lwidth(medthick) lcolor(black) noci) ///		
		(D40_f_first, label(Daughter  Age 40) offset(0) msymbol(D) mcolor(gs12)  lcolor(gs12)  lwidth(medthick) lcolor(gs12)  noci) ///		
		(S40_f_first, label(Son  Age 40)      offset(0) msymbol(D) mcolor(black) lcolor(black) lwidth(medthick) lcolor(black) noci) ///
		(D30_f_first, label(Daughter  Age 30) offset(0) msymbol(S) mcolor(gs12)  lcolor(gs12)  lwidth(medthick) lcolor(gs12)  noci) ///
		(S30_f_first, label(Son  Age 30)      offset(0) msymbol(S) mcolor(black) lcolor(black) lwidth(medthick) lcolor(black) noci) ///
	, title 	("Father's death", size(small)) 												///
				vertical recast(connected)  													///
				ytitle("") ylab (6.8 (0.1) 6.0, labsize(small) angle(0)) 						///
				xtitle("Years before/after death of the first parent", size(small)) 			///
				xlab (, labsize(small)) xscale(titlegap(2))									    ///
				legend(size(small) rows(3)) 													///
				graphregion(color(white) fcolor(white) icolor(white)) 							///
	name (fig_f, replace)	

** Combine graphs and save
graph combine fig_m fig_f, xcommon ycommon saving("$graphs/figure2.gph", replace)

est clear

*----------------------------------------------------------------------------------------------------*
*----------------------------------------------------------------------------------------------------*
